@@ -57,14 +57,14 @@ int STUDENTS_COMBO_BOXES_STYLE=STUDENTS_COMBO_BOXES_STYLE_SIMPLE;
 /**
 The FET version
 */
-const QString FET_VERSION="7.0.8";
+const QString FET_VERSION="7.3.1";
 
 /**
 The version number of the data format, useful when saving/restoring the history to/from the disk.
 On any change of the data format, no matter how small or large, this number must be updated;
 older or newer data history versions are not compatible.
 */
-const QString FET_DATA_FORMAT_VERSION="7.0.0"; //started from "6.15.1", since FET-6.15.1.
+const QString FET_DATA_FORMAT_VERSION="7.2.4"; //started from "6.15.1", since FET-6.15.1.
 
 /**
 The FET language
@@ -172,7 +172,7 @@ QString protect2(const QString& str) //used for HTML
 	p.replace("\"", "&quot;");
 	p.replace(">", "&gt;");
 	p.replace("<", "&lt;");
-	//p.replace("'", "&apos;");
+	//p.replace("'", "&#39;"); (note that "&apos;" does not work for HTML 4)
 	return p;
 }
 
@@ -183,7 +183,7 @@ QString protect2vert(const QString& str) //used for HTML
 	p.replace("\"", "&quot;");
 	p.replace(">", "&gt;");
 	p.replace("<", "&lt;");
-	//p.replace("'", "&apos;");
+	//p.replace("'", "&#39;"); (note that "&apos;" does not work for HTML 4)
 
 	QString returnstring;
 	for(int i=0; i<p.size();i++){
@@ -275,8 +275,13 @@ double customFETStrToDouble(const QString& str, bool* ok)
 ///////end tricks
 
 bool BEEP_AT_END_OF_GENERATION=true;
-bool ENABLE_COMMAND_AT_END_OF_GENERATION=true;
+bool ENABLE_COMMAND_AT_END_OF_GENERATION=false;
 QString commandAtEndOfGeneration=QString("");
+
+bool BEEP_AT_END_OF_GENERATION_EACH_TIMETABLE=false;
+bool ENABLE_COMMAND_AT_END_OF_GENERATION_EACH_TIMETABLE=false;
+QString commandAtEndOfGenerationEachTimetable=QString("");
+
 //bool DETACHED_NOTIFICATION=false;
 //int terminateCommandAfterSeconds=0;
 //int killCommandAfterSeconds=0;
