@@ -117,6 +117,14 @@ class AddOrModifyTimeConstraint: public QObject
 	int type;
 	TimeConstraint* oldtc;
 
+	//for teacher(s)/students (set) pair of mutually exclusive time slots
+	QGroupBox* firstTimeSlotGroupBox;
+	QGroupBox* secondTimeSlotGroupBox;
+	QComboBox* firstDayComboBox;
+	QComboBox* firstHourComboBox;
+	QComboBox* secondDayComboBox;
+	QComboBox* secondHourComboBox;
+
 	QCheckBox* showRelatedCheckBox;
 
 	QCheckBox* firstFilter_showRelatedCheckBox;
@@ -174,6 +182,9 @@ class AddOrModifyTimeConstraint: public QObject
 	QLabel* labelForSpinBox;
 	QSpinBox* spinBox;
 
+	QLabel* secondLabelForSpinBox;
+	QSpinBox* secondSpinBox;
+
 	QCheckBox* checkBox;
 
 	QGroupBox* periodGroupBox;
