@@ -29,7 +29,7 @@
 #include <QString>
 #include <QStringList>
 
-#include <QPlainTextEdit>
+#include <QTextEdit>
 
 //#include <QDateTime>
 //#include <QLocale>
@@ -49,6 +49,8 @@
 
 #include <QFileInfo>
 
+#include <QFont>
+
 #include "longtextmessagebox.h"
 
 #include <thread>
@@ -101,22 +103,27 @@ const QString settingsName=QString("TimetableGenerateUnsuccessfulForm");
 void runSingle()
 {
 	const int INF=2000000000;
-	bool impossible, timeExceeded;
+	bool restarted, impossible, timeExceeded;
 
 	gen.semaphorePlacedActivity.tryAcquire(); //this has effect after stopping the generation or if the timetable is impossible to solve
 	assert(gen.semaphorePlacedActivity.available()==0);
 	assert(gen.semaphoreFinished.available()==0);
-	gen.generateWithSemaphore(INF, impossible, timeExceeded, true); //true means threaded
+	gen.generateWithSemaphore(INF, restarted, impossible, timeExceeded, true); //true means threaded
 }
 
 TimetableGenerateForm::TimetableGenerateForm(QWidget* parent): QDialog(parent)
 {
 	setupUi(this);
 
+	QFont font(pausedLabel->font());
+	font.setBold(true);
+	pausedLabel->setFont(font);
+
 	currentResultsTextEdit->setReadOnly(true);
-	
+
 	connect(startPushButton, &QPushButton::clicked, this, &TimetableGenerateForm::start);
 	connect(stopPushButton, &QPushButton::clicked, this, &TimetableGenerateForm::stop);
+	connect(pausePushButton, &QPushButton::clicked, this, &TimetableGenerateForm::pause);
 	connect(writeResultsPushButton, &QPushButton::clicked, this, &TimetableGenerateForm::write);
 	connect(closePushButton, &QPushButton::clicked, this, &TimetableGenerateForm::closePressed);
 	connect(helpPushButton, &QPushButton::clicked, this, &TimetableGenerateForm::help);
@@ -132,8 +139,14 @@ TimetableGenerateForm::TimetableGenerateForm(QWidget* parent): QDialog(parent)
 
 	startPushButton->setDefault(true);
 
+	pausedLabel->setVisible(false);
+	
+	currentResultsTextEdit->setEnabled(true);
+	
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
+	pausePushButton->setDisabled(true);
+	pausePushButton->setText(tr("Pause", "Pause generation"));
 	stopHighestPushButton->setDisabled(true);
 	closePushButton->setEnabled(true);
 	writeResultsPushButton->setDisabled(true);
@@ -181,6 +194,9 @@ void TimetableGenerateForm::start(){
 	currentResultsTextEdit->setPlainText(TimetableGenerateForm::tr("Entering generation ... precomputing, please be patient"));
 
 	gen.abortOptimization=false;
+	gen.restart=false;
+	gen.paused=false;
+	gen.pausedTime=0;
 	bool ok=gen.precompute(this);
 	
 	if(!ok){
@@ -193,8 +209,14 @@ void TimetableGenerateForm::start(){
 		return;
 	}
 
+	pausedLabel->setVisible(false);
+
+	currentResultsTextEdit->setEnabled(true);
+
 	startPushButton->setDisabled(true);
 	stopPushButton->setEnabled(true);
+	pausePushButton->setEnabled(true);
+	pausePushButton->setText(tr("Pause", "Pause generation"));
 	stopHighestPushButton->setEnabled(true);
 	closePushButton->setDisabled(true);
 	writeResultsPushButton->setEnabled(true);
@@ -403,12 +425,12 @@ void TimetableGenerateForm::stop()
 	dialog.setWindowTitle(TimetableGenerateForm::tr("Generation stopped", "The title of a dialog, meaning that the generation of the timetable was stopped."));
 
 	QVBoxLayout* vl=new QVBoxLayout(&dialog);
-	QPlainTextEdit* te=new QPlainTextEdit();
+	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
 	QPushButton* pb=new QPushButton(TimetableGenerateForm::tr("OK"));
 
-	QHBoxLayout* hl=new QHBoxLayout(0);
+	QHBoxLayout* hl=new QHBoxLayout();
 	hl->addStretch(1);
 	hl->addWidget(pb);
 
@@ -424,8 +446,14 @@ void TimetableGenerateForm::stop()
 	dialog.exec();
 	saveFETDialogGeometry(&dialog, settingsName);
 
+	pausedLabel->setVisible(false);
+
+	currentResultsTextEdit->setEnabled(true);
+
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
+	pausePushButton->setDisabled(true);
+	pausePushButton->setText(tr("Pause", "Pause generation"));
 	stopHighestPushButton->setDisabled(true);
 	closePushButton->setEnabled(true);
 	writeResultsPushButton->setDisabled(true);
@@ -574,12 +602,12 @@ void TimetableGenerateForm::stopHighest()
 		"and highest stage timetable written."));
 
 	QVBoxLayout* vl=new QVBoxLayout(&dialog);
-	QPlainTextEdit* te=new QPlainTextEdit();
+	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
 	QPushButton* pb=new QPushButton(TimetableGenerateForm::tr("OK"));
 
-	QHBoxLayout* hl=new QHBoxLayout(0);
+	QHBoxLayout* hl=new QHBoxLayout();
 	hl->addStretch(1);
 	hl->addWidget(pb);
 
@@ -595,8 +623,14 @@ void TimetableGenerateForm::stopHighest()
 	dialog.exec();
 	saveFETDialogGeometry(&dialog, settingsName);
 
+	pausedLabel->setVisible(false);
+
+	currentResultsTextEdit->setEnabled(true);
+
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
+	pausePushButton->setDisabled(true);
+	pausePushButton->setText(tr("Pause", "Pause generation"));
 	stopHighestPushButton->setDisabled(true);
 	closePushButton->setEnabled(true);
 	writeResultsPushButton->setDisabled(true);
@@ -734,12 +768,12 @@ void TimetableGenerateForm::impossibleToSolve()
 	dialog.setWindowTitle(TimetableGenerateForm::tr("Generation impossible", "The title of a dialog, meaning that the generation of the timetable is impossible."));
 
 	QVBoxLayout* vl=new QVBoxLayout(&dialog);
-	QPlainTextEdit* te=new QPlainTextEdit();
+	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
 	QPushButton* pb=new QPushButton(TimetableGenerateForm::tr("OK"));
 
-	QHBoxLayout* hl=new QHBoxLayout(0);
+	QHBoxLayout* hl=new QHBoxLayout();
 	hl->addStretch(1);
 	hl->addWidget(pb);
 
@@ -786,8 +820,14 @@ void TimetableGenerateForm::impossibleToSolve()
 	dialog.exec();
 	saveFETDialogGeometry(&dialog, settingsName);
 
+	pausedLabel->setVisible(false);
+
+	currentResultsTextEdit->setEnabled(true);
+
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
+	pausePushButton->setDisabled(true);
+	pausePushButton->setText(tr("Pause", "Pause generation"));
 	stopHighestPushButton->setDisabled(true);
 	closePushButton->setEnabled(true);
 	writeResultsPushButton->setDisabled(true);
@@ -925,8 +965,14 @@ void TimetableGenerateForm::generationFinished()
 	msgBox.exec();
 	//QMessageBox::information(this, TimetableGenerateForm::tr("FET information"), s);
 
+	pausedLabel->setVisible(false);
+
+	currentResultsTextEdit->setEnabled(true);
+
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
+	pausePushButton->setDisabled(true);
+	pausePushButton->setText(tr("Pause", "Pause generation"));
 	stopHighestPushButton->setDisabled(true);
 	closePushButton->setEnabled(true);
 	writeResultsPushButton->setDisabled(true);
@@ -943,12 +989,14 @@ void TimetableGenerateForm::activityPlaced(int nThread, int na){
 	Q_UNUSED(nThread);
 	
 	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
+	
+	//if(gen.paused) -> DON'T DO THIS!!! We need to release the semaphore below.
+	//	return;
 
 	gen.myMutex.lock();
 	int t=gen.searchTime; //seconds
 	int mact=gen.maxActivitiesPlaced;
 	int seconds=gen.timeToHighestStage;
-
 	gen.myMutex.unlock();
 
 	gen.semaphorePlacedActivity.release();
@@ -1003,6 +1051,9 @@ void TimetableGenerateForm::activityPlaced(int nThread, int na){
 	s+="\n\n";
 	s+=tr("Max placed activities: %1 (at %2)", "%1 represents the maximum number of activities placed, %2 is a time interval").arg(mact).arg(tim);
 
+	//if(gen.paused)
+	//	s.prepend(tr("[PAUSED]", "Generation is paused")+QString("\n"));
+
 	currentResultsTextEdit->setPlainText(s);
 }
 
@@ -1042,6 +1093,9 @@ void TimetableGenerateForm::help()
 }
 
 void TimetableGenerateForm::write(){
+	if(gen.paused) //should not happen
+		assert(0);
+
 	gen.myMutex.lock();
 
 	Solution& c=gen.c;
@@ -1119,6 +1173,9 @@ void TimetableGenerateForm::write(){
 }
 
 void TimetableGenerateForm::writeHighestStage(){
+	if(gen.paused) //should not happen
+		assert(0);
+
 	gen.myMutex.lock();
 
 	Solution& c=gen.highestStageSolution;
@@ -1208,6 +1265,9 @@ void TimetableGenerateForm::closePressed()
 
 void TimetableGenerateForm::seeImpossible()
 {
+	if(gen.paused) //should not happen
+		assert(0);
+
 	QString s;
 
 	gen.myMutex.lock();
@@ -1243,12 +1303,12 @@ void TimetableGenerateForm::seeImpossible()
 	dialog.setWindowTitle(tr("FET - information about difficult activities"));
 
 	QVBoxLayout* vl=new QVBoxLayout(&dialog);
-	QPlainTextEdit* te=new QPlainTextEdit();
+	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
 	QPushButton* pb=new QPushButton(tr("OK"));
 
-	QHBoxLayout* hl=new QHBoxLayout(0);
+	QHBoxLayout* hl=new QHBoxLayout();
 	hl->addStretch(1);
 	hl->addWidget(pb);
 
@@ -1265,6 +1325,37 @@ void TimetableGenerateForm::seeImpossible()
 	saveFETDialogGeometry(&dialog, settingsName);
 }
 
+void TimetableGenerateForm::pause()
+{
+	if(!gen.paused){
+		writeResultsPushButton->setDisabled(true);
+		writeHighestStagePushButton->setDisabled(true);
+		seeImpossiblePushButton->setDisabled(true);
+
+		pausePushButton->setText(tr("Resume", "Resume generation"));
+		gen.paused=true;
+		
+		currentResultsTextEdit->setDisabled(true);
+		
+		pausedLabel->setVisible(true);
+
+		//QString s=tr("[PAUSED]", "Generation is paused")+QString("\n")+currentResultsTextEdit->toPlainText();
+		//currentResultsTextEdit->setPlainText(s);
+	}
+	else{
+		pausedLabel->setVisible(false);
+
+		currentResultsTextEdit->setEnabled(true);
+
+		pausePushButton->setText(tr("Pause", "Pause generation"));
+		gen.paused=false;
+
+		writeResultsPushButton->setEnabled(true);
+		writeHighestStagePushButton->setEnabled(true);
+		seeImpossiblePushButton->setEnabled(true);
+	}
+}
+
 void TimetableGenerateForm::seeInitialOrder()
 {
 	QString s=initialOrderOfActivities;
@@ -1275,12 +1366,12 @@ void TimetableGenerateForm::seeInitialOrder()
 	dialog.setWindowTitle(tr("FET - information about initial order of evaluation of activities"));
 
 	QVBoxLayout* vl=new QVBoxLayout(&dialog);
-	QPlainTextEdit* te=new QPlainTextEdit();
+	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
 	QPushButton* pb=new QPushButton(tr("OK"));
 
-	QHBoxLayout* hl=new QHBoxLayout(0);
+	QHBoxLayout* hl=new QHBoxLayout();
 	hl->addStretch(1);
 	hl->addWidget(pb);
 
