@@ -38,6 +38,9 @@
 #include <QScrollBar>
 
 #include <QVBoxLayout>
+#include <QHBoxLayout>
+
+#include <QFrame>
 
 #include <QDir>
 
@@ -45,6 +48,8 @@
 #include <QCoreApplication>
 #include <QtGlobal>
 
+#include <QSizePolicy>
+
 #include <QProcess>
 //#include <QTimer>
 
@@ -59,6 +64,8 @@
 
 #include <QFileInfo>
 
+#include <QFont>
+
 #include <QThread> //only for QThread::idealThreadCount()
 
 #include <mutex>
@@ -76,11 +83,18 @@ extern const QString PROGRAM;
 
 extern Generate gen;
 
+extern QString initialOrderOfActivities;
+
 //static Matrix1D<Worker> generateMultipleWorker;
 //static Matrix1D<QThread> generateMultipleThread;
+
 static int allNThreads;
+
 static Matrix1D<QSemaphore> semaphoreTimetableStarted;
 static Matrix1D<QSemaphore> semaphoreTimetableFinished;
+
+//static QSemaphore semaphoreRestarted;
+
 /*static Matrix1D<std::binary_semaphore> semaphoreTimetableStarted;
 static Matrix1D<std::binary_semaphore> semaphoreTimetableFinished;*/
 /*static Matrix1D<std::condition_variable> cvTimetableStarted;
@@ -110,15 +124,21 @@ static Matrix1D<time_t> process_start_time;
 
 static Matrix1D<TimetablingThread> timetablingThreads;
 
+const QString settingsNameMultiple=QString("TimetableGenerateMultipleInitialOrderForm");
+
 void TimetablingThread::startGenerating()
 {
 	//time_t start_time;
 
-	genMultiMatrix[_nThread].abortOptimization=false;
+	assert(genMultiMatrix[_nThread].abortOptimization==false);
+	assert(genMultiMatrix[_nThread].restart==false);
+	assert(genMultiMatrix[_nThread].paused==false);
+	assert(genMultiMatrix[_nThread].pausedTime==0);
 	
 	//time(&start_time);
 	time(&process_start_time[_nThread]);
 
+	bool restarted;
 	bool impossible;
 	bool timeExceeded;
 
@@ -128,7 +148,7 @@ void TimetablingThread::startGenerating()
 	genMultiMatrix[_nThread].semaphorePlacedActivity.tryAcquire(); //this has effect after forcingly stopping the generation on this thread
 	assert(genMultiMatrix[_nThread].semaphorePlacedActivity.available()==0);
 	assert(genMultiMatrix[_nThread].semaphoreFinished.available()==0);
-	genMultiMatrix[_nThread].generateWithSemaphore(timeLimit, impossible, timeExceeded, true); //true means threaded
+	genMultiMatrix[_nThread].generateWithSemaphore(timeLimit, restarted, impossible, timeExceeded, true); //true means threaded
 	//genMultiMatrix[_nThread].myMutex.lock();
 	if(genMultiMatrix[_nThread].abortOptimization){
 		//genMultiMatrix[_nThread].myMutex.unlock();
@@ -145,7 +165,44 @@ void TimetablingThread::startGenerating()
 	else
 		s=QString("");
 
-	if(impossible){
+	if(restarted){
+		s+=tr("Generation was stopped by user");
+
+		////////2011-05-26
+		int mact=genMultiMatrix[_nThread].maxActivitiesPlaced;
+		int mseconds=genMultiMatrix[_nThread].timeToHighestStage;
+
+		bool zero=false;
+		if(mseconds==0)
+			zero=true;
+		int hh=mseconds/3600;
+		mseconds%=3600;
+		int mm=mseconds/60;
+		mseconds%=60;
+		int ss=mseconds;
+		QString tim;
+		if(hh>0){
+			tim+=" ";
+			tim+=tr("%1 h", "hours").arg(hh);
+		}
+		if(mm>0){
+			tim+=" ";
+			tim+=tr("%1 m", "minutes").arg(mm);
+		}
+		if(ss>0 || zero){
+			tim+=" ";
+			tim+=tr("%1 s", "seconds").arg(ss);
+		}
+		tim.remove(0, 1);
+		s+=QString(". ");
+		s+=tr("Max placed activities: %1 (at %2)", "%1 represents the maximum number of activities placed, %2 is a time interval").arg(mact).arg(tim);
+		///////
+
+		s+=QString(".");
+
+		ok=false;
+	}
+	else if(impossible){
 		s+=tr("Timetable impossible to generate");
 		s+=QString(".");
 		ok=false;
@@ -192,7 +249,9 @@ void TimetablingThread::startGenerating()
 		
 		time_t finish_time;
 		time(&finish_time);
-		int seconds=int(difftime(finish_time, process_start_time[_nThread]));
+		int seconds=int(difftime(finish_time, process_start_time[_nThread]))-genMultiMatrix[_nThread].pausedTime;
+		if(seconds<0)
+			seconds=0;
 		int hours=seconds/3600;
 		seconds%=3600;
 		int minutes=seconds/60;
@@ -215,7 +274,11 @@ void TimetablingThread::startGenerating()
 
 	emit timetableGenerated(_nThread, nOverallTimetable+1, s, ok);
 
+	//if(restarted)
+	//	semaphoreRestarted.release();
+
 	semaphoreTimetableFinished[_nThread].acquire();
+
 	/*std::mutex mtx;
 	std::unique_lock<std::mutex> lck(mtx);
 	cvTimetableFinished[_nThread].wait(lck);*/
@@ -254,6 +317,12 @@ TimetableGenerateMultipleForm::TimetableGenerateMultipleForm(QWidget* parent): Q
 	
 	//Not necessary, this property is set in the ui file.
 	//timetablesTabWidget->setUsesScrollButtons(true);
+
+	pausedLabel->setVisible(false);
+	
+	QFont font(pausedLabel->font());
+	font.setBold(true);
+	pausedLabel->setFont(font);
 	
 	currentResultsTextEdit->setReadOnly(true);
 	
@@ -263,11 +332,16 @@ TimetableGenerateMultipleForm::TimetableGenerateMultipleForm(QWidget* parent): Q
 	connect(stopPushButton, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::stop);
 	connect(closePushButton, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::closePressed);
 	connect(helpPushButton, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::help);
+	connect(seeInitialOrderPushButton, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::seeInitialOrder);
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
 	
 	generation_running_multi=false;
+	
+	pausePushButton->setDisabled(true);
+	pausePushButton->setText(tr("Pause", "Pause generation"));
+	restartPushButton->setDisabled(true);
 
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
@@ -275,8 +349,20 @@ TimetableGenerateMultipleForm::TimetableGenerateMultipleForm(QWidget* parent): Q
 	minutesGroupBox->setEnabled(true);
 	timetablesGroupBox->setEnabled(true);
 	threadsGroupBox->setEnabled(true);
+	seeInitialOrderPushButton->setDisabled(true);
 
 	labels.append(textLabel);
+	pausedLabels.append(pausedLabel);
+
+	pausePushButtons.append(pausePushButton);
+	pausePushButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+	connect(pausePushButton, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::pauseCurrentThread);
+
+	restartPushButtons.append(restartPushButton);
+	restartPushButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+	//QPushButton* pb=new QPushButton(tr("Restart"), wd);
+	//pb->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+	connect(restartPushButton, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::restartCurrentThread);
 
 	nThreadsSpinBox->setMinimum(1);
 	nThreadsSpinBox->setMaximum(std::max(1, QThread::idealThreadCount()));
@@ -325,6 +411,16 @@ void TimetableGenerateMultipleForm::nThreadsChanged(int nt)
 			timetablesTabWidget->removeTab(i);
 			assert(labels.count()>0);
 			labels.removeLast();
+
+			assert(restartPushButtons.count()>0);
+			restartPushButtons.removeLast();
+
+			assert(pausePushButtons.count()>0);
+			pausePushButtons.removeLast();
+
+			assert(pausedLabels.count()>0);
+			pausedLabels.removeLast();
+
 			delete wd;
 		}
 		
@@ -337,13 +433,50 @@ void TimetableGenerateMultipleForm::nThreadsChanged(int nt)
 		for(int i=oldN; i<nt; i++){
 			QWidget* wd=new QWidget(timetablesTabWidget);
 			
+			QLabel* plb=new QLabel(tr("[PAUSED]", "Generation is paused"), wd);
+			plb->setVisible(false);
+			///////
+			QFont font(plb->font());
+			font.setBold(true);
+			plb->setFont(font);
+			
 			QLabel* lb=new QLabel(tr("Current timetable: 0 out of 0 activities placed, 0h 0m 0s\nMax placed activities: 0 (at 0 s)"), wd);
-			QVBoxLayout* bl=new QVBoxLayout(wd);
-			bl->addWidget(lb);
+			
+			QVBoxLayout* lbl=new QVBoxLayout;
+			lbl->addWidget(plb);
+			lbl->addWidget(lb);
+
+			QPushButton* ppb=new QPushButton(tr("Pause", "Pause generation"), wd);
+			ppb->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+			ppb->setDisabled(true);
+			connect(ppb, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::pauseCurrentThread);
+
+			// https://stackoverflow.com/questions/10053839/how-does-designer-create-a-line-widget
+			QFrame* line=new QFrame(wd);
+			line->setFrameShape(QFrame::HLine);
+			line->setFrameShadow(QFrame::Sunken);
+
+			QPushButton* rpb=new QPushButton(tr("Restart"), wd);
+			rpb->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+			rpb->setDisabled(true);
+			connect(rpb, &QPushButton::clicked, this, &TimetableGenerateMultipleForm::restartCurrentThread);
+
+			QVBoxLayout* vbl=new QVBoxLayout;
+			vbl->addWidget(ppb);
+			vbl->addWidget(line);
+			vbl->addWidget(rpb);
+
+			QHBoxLayout* hbl=new QHBoxLayout(wd);
+			hbl->addLayout(lbl);
+			hbl->addStretch();
+			hbl->addLayout(vbl);
 			
 			timetablesTabWidget->addTab(wd, QString::number(i+1));
 			
 			labels.append(lb);
+			pausePushButtons.append(ppb);
+			restartPushButtons.append(rpb);
+			pausedLabels.append(plb);
 		}
 		
 		timetablesTabWidget->setCurrentIndex(timetablesTabWidget->count()-1);
@@ -546,6 +679,15 @@ void TimetableGenerateMultipleForm::start(){
 
 	//assert(controllersList.count()==0);
 	for(int t=0; t<nThreads; t++){
+		pausePushButtons.at(t)->setEnabled(true);
+		pausePushButtons.at(t)->setText(tr("Pause", "Pause generation"));
+		
+		pausedLabels[t]->setVisible(false);
+		
+		labels[t]->setEnabled(true);
+
+		restartPushButtons.at(t)->setEnabled(true);
+
 		//generateMultipleWorker[t].disconnect(); //disconnect all connections for this QThread
 		genMultiMatrix[t].disconnect(); //disconnect all connections for this Generate
 		
@@ -572,6 +714,7 @@ void TimetableGenerateMultipleForm::start(){
 	timetablesGroupBox->setDisabled(true);
 	closePushButton->setDisabled(true);
 	threadsGroupBox->setDisabled(true);
+	seeInitialOrderPushButton->setEnabled(true);
 
 	nGeneratedTimetables=0;
 	nSuccessfullyGeneratedTimetables=0;
@@ -591,6 +734,11 @@ void TimetableGenerateMultipleForm::start(){
 	
 	for(int t=0; t<nThreads; t++){
 		genMultiMatrix[t].c.makeUnallocated(gt.rules);
+
+		genMultiMatrix[t].abortOptimization=false;
+		genMultiMatrix[t].restart=false;
+		genMultiMatrix[t].paused=false;
+		genMultiMatrix[t].pausedTime=0;
 		
 		timetablingThreads[t].nOverallTimetable=t;
 
@@ -613,6 +761,7 @@ void TimetableGenerateMultipleForm::start(){
 		//2023-09-27: Must put [=] here, [&] does not work, gives various crashes. I am not sure why, I think maybe because
 		//the TimetablingThread must be reinstantiated in the detached thread. Probably t goes out of scope.
 		//std::thread([=]{timetablingThreads[t].startGenerating();}).detach();
+
 		std::thread([t]{timetablingThreads[t].startGenerating();}).detach();
 	}
 }
@@ -680,7 +829,7 @@ void TimetableGenerateMultipleForm::timetableGenerated(int nThread, int timetabl
 
 		QString s=QString("");
 		s+=tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description").arg(timetable).arg(description);
-		currentResultsTextEdit->appendPlainText(s);
+		currentResultsTextEdit->append(s);
 	
 		bool begin;
 		if(nGeneratedTimetables==1)
@@ -720,6 +869,23 @@ void TimetableGenerateMultipleForm::timetableGenerated(int nThread, int timetabl
 				conflictsString+=t+"\n";
 			
 			updateAllTimetableViewDialogs();
+
+			if(BEEP_AT_END_OF_GENERATION_EACH_TIMETABLE)
+				QApplication::beep();
+
+			if(ENABLE_COMMAND_AT_END_OF_GENERATION_EACH_TIMETABLE){
+				QString s=commandAtEndOfGenerationEachTimetable.simplified();
+				if(!s.isEmpty()){
+					QStringList sl=s.split(" ");
+					assert(sl.count()>=1);
+					QString command=sl.at(0);
+					QStringList arguments;
+					for(int i=1; i<sl.count(); i++)
+						arguments.append(sl.at(i));
+					
+					QProcess::startDetached(command, arguments);
+				}
+			}
 		}
 	}
 
@@ -746,6 +912,11 @@ void TimetableGenerateMultipleForm::timetableGenerated(int nThread, int timetabl
 	
 		genMultiMatrix[nThread].c.makeUnallocated(gt.rules);
 
+		genMultiMatrix[nThread].abortOptimization=false;
+		genMultiMatrix[nThread].restart=false;
+		genMultiMatrix[nThread].paused=false;
+		genMultiMatrix[nThread].pausedTime=0;
+
 		//Controller* controller=new Controller();
 		//controllersList[nThread]=controller;
 		
@@ -846,6 +1017,67 @@ void TimetableGenerateMultipleForm::timetableGenerated(int nThread, int timetabl
 	}
 }
 
+void TimetableGenerateMultipleForm::restartCurrentThread()
+{
+	if(!generation_running_multi){
+		return;
+	}
+	
+	int t=timetablesTabWidget->currentIndex();
+	assert(t>=0);
+	assert(t<nThreadsSpinBox->value());
+	
+	restartPushButtons.at(t)->setDisabled(true);
+	pausePushButtons.at(t)->setDisabled(true);
+	pausePushButtons.at(t)->setText(tr("Pause", "Pause generation"));
+	
+	pausedLabels.at(t)->setVisible(false);
+	
+	labels.at(t)->setEnabled(true);
+	
+	if(genMultiMatrix[t].isRunning && !genMultiMatrix[t].restart){
+		genMultiMatrix[t].restart=true;
+		//semaphoreRestarted.acquire();
+		//genMultiMatrix[t].semaphorePlacedActivity.release();
+		//genMultiMatrix[t].semaphoreFinished.acquire();
+	}
+
+	restartPushButtons.at(t)->setEnabled(true);
+	pausePushButtons.at(t)->setEnabled(true);
+}
+
+void TimetableGenerateMultipleForm::pauseCurrentThread()
+{
+	if(!generation_running_multi){
+		return;
+	}
+	
+	int t=timetablesTabWidget->currentIndex();
+	assert(t>=0);
+	assert(t<nThreadsSpinBox->value());
+	
+	if(genMultiMatrix[t].isRunning){
+		if(!genMultiMatrix[t].paused){
+			pausePushButtons.at(t)->setText(tr("Resume", "Resume generation"));
+			genMultiMatrix[t].paused=true;
+
+			labels[t]->setDisabled(true);
+
+			pausedLabels[t]->setVisible(true);
+			//QString s=tr("[PAUSED]", "Generation is paused")+QString("\n")+labels[t]->text();
+			//labels[t]->setText(s);
+		}
+		else{
+			pausedLabels[t]->setVisible(false);
+			
+			labels[t]->setEnabled(true);
+
+			pausePushButtons.at(t)->setText(tr("Pause", "Pause generation"));
+			genMultiMatrix[t].paused=false;
+		}
+	}
+}
+
 void TimetableGenerateMultipleForm::stop()
 {
 	if(!generation_running_multi){
@@ -857,6 +1089,14 @@ void TimetableGenerateMultipleForm::stop()
 	//assert(controllersList.count()==nThreadsSpinBox->value());
 
 	for(int t=0; t<nThreadsSpinBox->value(); t++){
+		pausedLabels[t]->setVisible(false);
+		
+		labels[t]->setEnabled(true);
+
+		pausePushButtons.at(t)->setDisabled(true);
+		pausePushButtons.at(t)->setText(tr("Pause", "Pause generation"));
+		restartPushButtons.at(t)->setDisabled(true);
+		
 		/*genMultiMatrix[t].myMutex.lock();
 		bool iR=genMultiMatrix[t].isRunning;
 		genMultiMatrix[t].myMutex.unlock();*/
@@ -954,12 +1194,12 @@ void TimetableGenerateMultipleForm::stop()
 	else{
 		s+=QString("\n\n");
 		s+=TimetableGenerateMultipleForm::tr("From the interface you can access the last highest-stage timetable and on the disk"
-		 " there were saved all the highest-stage timetables (the highest number of activities reached is %1, reached in %2 timetables).")
+		 " there were saved all the highest-stage timetables (the highest number of scheduled activities is %1, reached in %2 timetables).")
 		 .arg(highestPlacedActivities).arg(highestStageSolutions.count());
 		
 		stringForDisk+=QString("\n\n");
 		stringForDisk+=TimetableGenerateMultipleForm::tr("On the disk there were saved all the highest-stage timetables (the highest number"
-		 " of activities reached is %1, reached in %2 timetables).").arg(highestPlacedActivities).arg(highestStageSolutions.count());
+		 " of scheduled activities is %1, reached in %2 timetables).").arg(highestPlacedActivities).arg(highestStageSolutions.count());
 
 		for(int i=0; i<highestStageSolutions.count(); i++){
 			Solution* sol=highestStageSolutions.at(i);
@@ -1006,10 +1246,10 @@ void TimetableGenerateMultipleForm::stop()
 			//description+=QString(".");
 			
 			if(i>=1 || currentResultsTextEdit->toPlainText().isEmpty())
-				currentResultsTextEdit->appendPlainText(tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
+				currentResultsTextEdit->append(tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
 				 .arg(nTimetable).arg(description));
 			else
-				currentResultsTextEdit->appendPlainText(QString("\n")+tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
+				currentResultsTextEdit->append(QString("\n")+tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
 				 .arg(nTimetable).arg(description));
 			ms3+=tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
 			 .arg(nTimetable).arg(description)+QString("\n");
@@ -1131,12 +1371,12 @@ void TimetableGenerateMultipleForm::generationFinished()
 	else{
 		ms+=QString("\n\n");
 		ms+=TimetableGenerateMultipleForm::tr("From the interface you can access the last highest-stage timetable and on the disk"
-		 " there were saved all the highest-stage timetables (the highest number of activities reached is %1, reached in %2 timetables).")
+		 " there were saved all the highest-stage timetables (the highest number of scheduled activities is %1, reached in %2 timetables).")
 		 .arg(highestPlacedActivities).arg(highestStageSolutions.count());
 
 		stringForDisk+=QString("\n\n");
 		stringForDisk+=TimetableGenerateMultipleForm::tr("On the disk there were saved all the highest-stage timetables (the highest number"
-		 " of activities reached is %1, reached in %2 timetables).").arg(highestPlacedActivities).arg(highestStageSolutions.count());
+		 " of scheduled activities is %1, reached in %2 timetables).").arg(highestPlacedActivities).arg(highestStageSolutions.count());
 
 		for(int i=0; i<highestStageSolutions.count(); i++){
 			Solution* sol=highestStageSolutions.at(i);
@@ -1183,10 +1423,10 @@ void TimetableGenerateMultipleForm::generationFinished()
 			//description+=QString(".");
 
 			if(i>=1 || currentResultsTextEdit->toPlainText().isEmpty())
-				currentResultsTextEdit->appendPlainText(tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
+				currentResultsTextEdit->append(tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
 				 .arg(nTimetable).arg(description));
 			else
-				currentResultsTextEdit->appendPlainText(QString("\n")+tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
+				currentResultsTextEdit->append(QString("\n")+tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
 				 .arg(nTimetable).arg(description));
 			ms3+=tr("Timetable no: %1 => %2", "%1 is the number of this timetable when generating multiple timetables, %2 is its description")
 			 .arg(nTimetable).arg(description)+QString("\n");
@@ -1293,6 +1533,16 @@ void TimetableGenerateMultipleForm::generationFinished()
 	msgBox.exec();
 	//QMessageBox::information(this, TimetableGenerateMultipleForm::tr("FET information"), ms);
 	
+	for(int t=0; t<nThreadsSpinBox->value(); t++){
+		pausedLabels[t]->setVisible(false);
+		
+		labels[t]->setEnabled(true);
+
+		pausePushButtons.at(t)->setDisabled(true);
+		pausePushButtons.at(t)->setText(tr("Pause", "Pause generation"));
+		restartPushButtons.at(t)->setDisabled(true);
+	}
+	
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
 	minutesGroupBox->setEnabled(true);
@@ -1321,6 +1571,9 @@ void TimetableGenerateMultipleForm::activityPlaced(int nThread, int na)
 {
 	assert(nThread>=0);
 	assert(nThread<nThreadsSpinBox->value());
+	
+	//if(genMultiMatrix[nThread].paused) -> DON'T DO THIS!!! We need to release the semaphore below.
+	//	return;
 
 	genMultiMatrix[nThread].myMutex.lock();
 	int seconds=genMultiMatrix[nThread].searchTime; //seconds
@@ -1370,7 +1623,11 @@ void TimetableGenerateMultipleForm::activityPlaced(int nThread, int na)
 	s+=tr("Max placed activities: %1 (at %2)", "%1 represents the maximum number of activities placed, %2 is a time interval").arg(mact).arg(tim);
 	///////
 	
-	labels[nThread]->setText(tr("Current timetable: %1 out of %2 activities placed, %3h %4m %5s")
+	//QString prefixS;
+	//if(genMultiMatrix[nThread].paused)
+	//	prefixS=tr("[PAUSED]", "Generation is paused")+QString("\n");
+	
+	labels[nThread]->setText(/*prefixS+*/tr("Current timetable: %1 out of %2 activities placed, %3h %4m %5s")
 	 .arg(na)
 	 .arg(gt.rules.nInternalActivities)
 	 .arg(hours)
@@ -1383,3 +1640,35 @@ void TimetableGenerateMultipleForm::closePressed()
 	if(!generation_running_multi)
 		this->close();
 }
+
+void TimetableGenerateMultipleForm::seeInitialOrder()
+{
+	QString s=initialOrderOfActivities;
+
+	//show the message in a dialog
+	QDialog dialog(this);
+	
+	dialog.setWindowTitle(tr("FET - information about initial order of evaluation of activities"));
+
+	QVBoxLayout* vl=new QVBoxLayout(&dialog);
+	QTextEdit* te=new QTextEdit();
+	te->setPlainText(s);
+	te->setReadOnly(true);
+	QPushButton* pb=new QPushButton(tr("OK"));
+
+	QHBoxLayout* hl=new QHBoxLayout();
+	hl->addStretch(1);
+	hl->addWidget(pb);
+
+	vl->addWidget(te);
+	vl->addLayout(hl);
+	connect(pb, &QPushButton::clicked, &dialog, &QDialog::close);
+
+	dialog.resize(700,500);
+	centerWidgetOnScreen(&dialog);
+	restoreFETDialogGeometry(&dialog, settingsNameMultiple);
+
+	setParentAndOtherThings(&dialog, this);
+	dialog.exec();
+	saveFETDialogGeometry(&dialog, settingsNameMultiple);
+}
